/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#include "dl_arc.h"
#include "dl_math.h"


/**
 * Default constructor.
 */
DL_Arc::DL_Arc (DL_Vector center,
                double rad,
		            double a1, double a2,
								bool reversed)
 : DL_Circle (center, rad)
{
	angle1 = a1;
	angle2 = a2;
	if (reversed) setFlag (E_REVERSED);
	calculateEndpoints ();
	calculateBorders ();
}


/**
 * Recalculates the endpoints.
 */
void 
DL_Arc::calculateEndpoints ()
{
	startPoint.set (center.x + cos (angle1/ARAD) * radius,
	                center.y + sin (angle1/ARAD) * radius);
	endPoint.set (center.x + cos (angle2/ARAD) * radius,
	              center.y + sin (angle2/ARAD) * radius);
}


/**
 * Recalculates the border.
 */
void 
DL_Arc::calculateBorders ()
{
	double minX = min (startPoint.x, endPoint.x);
	double minY = min (startPoint.y, endPoint.y);
	double maxX = max (startPoint.x, endPoint.x);
	double maxY = max (startPoint.y, endPoint.y);

	double a1 = !isReversed () ? angle1 : angle2;
	double a2 = !isReversed () ? angle2 : angle1;

	if ((a1<180.0 && a2>180.0) ||
	    (a1>a2    && a2>180.0) ||
	    (a1>a2    && a1<180.0) ) {

		minX = min (center.x - radius, minX);
	}
	
	if (a1 > a2) {
		maxX = max (center.x + radius, maxX);
	}

	if ((a1<270.0 && a2>270.0) ||
	    (a1>a2    && a2>270.0) ||
	    (a1>a2    && a1<270.0) ) {

		minY = min (center.y - radius, minY);
	}

	if ((a1<90.0 && a2>90.0) ||
      (a1>a2   && a2>90.0) ||
      (a1>a2   && a1<90.0) ) {

		maxY = max (center.y + radius, maxY);
	}
	
	min.set(minX, minY);
	max.set(maxX, maxY);
}


/**
 * Dumps the point's data to stdout.
 */
std::ostream& operator << (std::ostream& os, DL_Arc& a)
{
	os << "Arc: " << a.center << " " 
	   << a.radius << " " 
		 << a.angle1 << " " << a.angle2 << "\n";
  return os;
}


// EOF
