/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#ifndef DL_ARC_H
#define DL_ARC_H

#include "dl_circle.h"


// Additional flags for arcs (0x00010000 - 0x80000000):
#define E_REVERSED     0x00010000


/**
 * Class for an arc entity.
 *
 * @author Andrew Mustun
 */
class DL_Arc : public DL_Circle {
	public:
		DL_Arc (DL_Vector center, 
		        double rad, 
						double a1, double a2,
						bool reversed=false);
		
		/**	\return DL_ENTITY_ARC
		*/
		virtual int rtti() { return DL_ENTITY_ARC; }
		
		/** Returns the start angle of this arc */
		double getAngle1 () { return angle1; }
		/** Returns the end angle of this arc */
		double getAngle2 () { return angle2; }
		
		/** Returns true if the arc is reversed (clockwise) */
		bool   isReversed () { return getFlag (E_REVERSED); }
		
		friend std::ostream& operator << (std::ostream& os, DL_Arc& a);
		
	protected:
		virtual void calculateEndpoints ();
		virtual void calculateBorders ();
		
	protected:
		double angle1;
		double angle2;
};

#endif
