/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#ifndef DL_ENTITY_H
#define DL_ENTITY_H

#include "dl_vector.h"
#include "dl_flags.h"
#include "dl_math.h"


// Flags for all entities (0x00000001 - 0x00008000):
#define E_VISIBLE     0x00000001		//! Entity is visible


// Entity types returned by the rtti() method
#define DL_ENTITY_UNKNOWN  0
#define DL_ENTITY_LAYER    10
#define DL_ENTITY_SETTING  50
#define DL_ENTITY_POINT    100
#define DL_ENTITY_LINE     101
#define DL_ENTITY_POLYLINE 102
#define DL_ENTITY_VERTEX   103
#define DL_ENTITY_ARC      104
#define DL_ENTITY_CIRCLE   105
#define DL_ENTITY_TEXT     106


/**
 * Base class for an entity (line, arc, circle, ...)
 *
 * @author Andrew Mustun
 */
class DL_Entity : public DL_Flags {
	public:
		DL_Entity ();
		
		/**	Must be overwritten to return the rtti of this entity 
		    (e.g. DL_ENTITY_ARC).
		    \return DL_ENTITY_UNKNOWN for virtual items (should never happen).
				        otherwise the item type.
		*/
		virtual int rtti() { return DL_ENTITY_UNKNOWN; }

		virtual bool isContainer() { return false; }
		
		DL_Vector getStartPoint() { return startPoint; }
		DL_Vector getEndPoint() { return endPoint; }
		
		DL_Vector getMin() { return min; }
		DL_Vector getMax() { return max; }
		
		DL_Entity* getThis () { return this; }
		
	protected:
		/** Must be overwritten to recalculate the borders of this entity. */
		virtual void calculateBorders () = 0;

	protected:
		DL_Vector startPoint;
		DL_Vector endPoint;
		
		DL_Vector min;                      //! minimum coordinates
		DL_Vector max;                      //! maximum coordinates
};

#endif
