/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#include "dl_entitycontainer.h"

#include <values.h>

#include "dl_math.h"


/**
 * Default constructor.
 */
DL_EntityContainer::DL_EntityContainer ()
{
	min.set (MAXDOUBLE, MAXDOUBLE, MAXDOUBLE);
	max.set (MINDOUBLE, MINDOUBLE, MINDOUBLE);
}



/**
 * Adds a element to the graphic.
 */
void
DL_EntityContainer::addEntity (DL_Entity* entity)
{
	std::vector<DL_Entity*>::iterator it = entities.end();
	entities.insert (it, entity);
	adjustBorders (entity);
}



/**
 * Adjusts the borders of this graphic (max/min values)
 */
void
DL_EntityContainer::adjustBorders (DL_Entity* entity)
{
	min = DL_Vector::minimum (entity->getMin(),min);
	max = DL_Vector::maximum (entity->getMax(),max);
}



/**
 * Returns the first entity or NULL if this graphic is empty.
 */
DL_Entity*
DL_EntityContainer::first()
{
	iterator = entities.begin();
	if (iterator==entities.end ()) return 0;
	else                           return (*iterator);
}



/**
 * Returns the next entity or NULL if the last entity returned by next() 
 * was the last entity in the container.
 */
DL_Entity*
DL_EntityContainer::next()
{
	iterator++;
	if (iterator>=entities.end ()) return 0;
	else                           return (*iterator);
}



/**
 * Returns the first single entity or NULL if this graphic is empty.
 * Single entities can not be polylines or texts. Only lines, arcs, ...
 */
DL_Entity*
DL_EntityContainer::firstSingle ()
{
	singleIterator = 0;
	iterator = entities.begin ();
	
	if (iterator==entities.end ()) {
		iterator = 0;
	}
	else {
		if ((*iterator)->isContainer ()) {
			singleIterator = ((DL_EntityContainer*)(*iterator))->getEntities ().begin ();
			return (*singleIterator);
		}
	}
	
	return (*iterator);
}



/**
 * Returns the next single entity or NULL if the last entity returned by next() 
 * was the last entity in the container.
 */
DL_Entity*
DL_EntityContainer::nextSingle ()
{
	if (singleIterator) {
		singleIterator++;
		if (singleIterator>=((DL_EntityContainer*)(*iterator))->getEntities ().end ()) {
			singleIterator = 0;
		}
	}

	if (singleIterator==0) {
		iterator++;
    if (iterator>=entities.end ()) return 0;
    else                           return (*iterator);
	}
	else {
		return (*singleIterator);
	}
	
}


// EOF
