/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#ifndef DL_ENTITYCONTAINER_H
#define DL_ENTITYCONTAINER_H

#include <vector.h>
#include "dl_entity.h"
#include "dl_point.h"
#include "dl_line.h"
#include "dl_arc.h"
#include "dl_circle.h"

/**                                                                                              
 * Something which contains entities (e.g. graphic or a polyline)
 *
 * @author Andrew Mustun
 */
class DL_EntityContainer {
	public:
		DL_EntityContainer ();
		
		void addEntity (DL_Entity* entity);
		DL_Entity* first ();
		DL_Entity* next ();
		DL_Entity* firstSingle ();
		DL_Entity* nextSingle ();
		std::vector<DL_Entity*> getEntities () { return entities; }
		
		void adjustBorders (DL_Entity* entity);
		DL_Vector getMin() { return min; }
		DL_Vector getMax() { return max; }
    
	protected:
		std::vector<DL_Entity*> entities;		//! entities in the container
		std::vector<DL_Entity*>::const_iterator iterator;
																				//! iterator for first() / next()
		std::vector<DL_Entity*>::const_iterator singleIterator;
		                                        //! iterator for firstSingle() / nextSingle()
																				
		DL_Vector min;       //! minimum coordinates
		DL_Vector max;       //! maximum coordinates
};


#endif
