/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#include "dl_graphic.h"

#include <values.h>

#include "dl_math.h"


/**
 * Default constructor.
 */
DL_Graphic::DL_Graphic ()
{
	unit = DL_Units::None;
}



/**
 * Adds a layer to the graphic. Simple wrapper added 
 * for convenience.
 */
void
DL_Graphic::addLayer (DL_Layer* layer)
{
	layerList.addLayer (layer);
}



/**
 * Dumps the entities to stdout.
 */
std::ostream& operator << (std::ostream& os, DL_Graphic& g)
{
	os << "Graphic: \n";
	os << "Borders: " << g.min << " - " << g.max << "\n";
	os << "Unit: " << DL_Units::unit2string (g.unit) << "\n";
	os << g.layerList << "\n";
	
	for (std::vector<DL_Entity*>::const_iterator it = g.entities.begin();
			 it != g.entities.end();
			 it++)
	{
		switch ((*it)->rtti()) {
			case DL_ENTITY_POINT:
				os << *(DL_Point*)(*it)->getThis ();		// ARGH!!
				break;
				
			case DL_ENTITY_LINE:
				os << *(DL_Line*)(*it)->getThis ();
				break;

			case DL_ENTITY_POLYLINE:
				os << *(DL_Polyline*)(*it)->getThis ();
				break;

			case DL_ENTITY_ARC:
				os << *(DL_Arc*)(*it)->getThis ();
				break;
			
			case DL_ENTITY_CIRCLE:
				os << *(DL_Circle*)(*it)->getThis ();
				break;
				
			case DL_ENTITY_TEXT:
				os << *(DL_Text*)(*it)->getThis ();
				break;
				
			default:
				break;
		}
	}
	
	return os;
}


// EOF
