/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#include "dl_polyline.h"
#include "dl_line.h"
#include "dl_arc.h"


/**
 * Default constructor.
 * \param x Startpoint 
 */
DL_Polyline::DL_Polyline (DL_Vector v)
{
	startPoint = v;
	//calculateBorders ();
}


/**
 * Recalculates the border.
 */
void 
DL_Polyline::calculateBorders ()
{
	
}


/**
 * Dumps the point's data to stdout.
 */
std::ostream& operator << (std::ostream& os, DL_Polyline& l)
{
	os << "Polyline: " << l.startPoint << " " << l.endPoint << "\n";

	for (std::vector<DL_Entity*>::const_iterator it = l.entities.begin();
	     it != l.entities.end();
	     it++)
	{
		switch ((*it)->rtti()) {
			case DL_ENTITY_LINE:
				os << "  " << *(DL_Line*)(*it)->getThis ();    // ARGH!!
				break;

			case DL_ENTITY_ARC:
				os << "  " << *(DL_Arc*)(*it)->getThis ();
				break;

			default:
				break;
		}
	}

	return os;
}


/**
 * Adds an entity from the endpoint of the last element or 
 * the startpoint to the point 'v'.
 */
void
DL_Polyline::addEntity (DL_Vector v)
{
	DL_Vector entityStart;

	std::vector<DL_Entity*>::iterator it = entities.end() - 1;
	if (entities.empty ()) {
		entityStart = startPoint;
	}
	else {
		entityStart = ((DL_Entity*)(*it))->getEndPoint ();
	}
	DL_Entity* entity = new DL_Line (entityStart, v);
	entities.insert (it+1, entity);
}


// EOF
