/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#ifndef DL_TEXT_H
#define DL_TEXT_H

#include "dl_entity.h"
#include "dl_entitycontainer.h"

/**
 * Class for a text entity.
 *
 * @author Andrew Mustun
 */
class DL_Text : public DL_Entity, public DL_EntityContainer {
	public:
		DL_Text (DL_Vector p, const char* t, double ang, double hgt);
		
		/**	\return DL_ENTITY_POINT
		*/
		virtual int rtti() { return DL_ENTITY_TEXT; }

		virtual bool isContainer() { return true; }
		
		void setText (const char* t);
		char* getText () { return text; }
		double getAngle () { return angle; }
		double getHeight () { return height; }
		
		friend std::ostream& operator << (std::ostream& os, DL_Text& p);
		
	protected:
		/** Recalculates the borders of this entity. */
		virtual void calculateBorders ();
		
	private:
		char* text;
		double angle;
		double height;
};

#endif
