/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#include "dl_units.h"


/**
 * Gets the sign for a unit enum.
 *
 * \param _unit The unit as enum
 */
char*
DL_Units::unit2sign(Unit unit)
{
	switch( unit ) {
    case None:       return "";
    case Inch:       return "\"";
    case Foot:       return "'";
    case Mile:       return "mi";
    case Millimeter: return "mm";
    case Centimeter: return "cm";
    case Meter:      return "m";
    case Kilometer:  return "km";
    case Microinch:  return "\"";
    case Mil:        return "mil";
    case Yard:       return "yd";
    case Angstrom:   return "A";
    case Nanometer:  return "nm";
    case Micron:     return "m";
    case Decimeter:  return "dm";
    case Decameter:  return "dam";
    case Hectometer: return "hm";
    case Gigameter:  return "Gm";
    case Astro:      return "astro";
    case Lightyear:  return "ly";
    case Parsec:     return "pc";
  }

  return "";
}



/** 
 * Gets unit enum from a string:
 */
DL_Units::Unit
DL_Units::string2unit(const char* unit, bool* ok)
{
	if(ok) *ok=true;

  if(unit=="None")         return None;
  if(unit=="Inch")         return Inch;
  if(unit=="Foot")         return Foot;
  if(unit=="Mile")         return Mile;
  if(unit=="Millimeter")   return Millimeter;
  if(unit=="Centimeter")   return Centimeter;
  if(unit=="Meter")        return Meter;
  if(unit=="Kilometer")    return Kilometer;
  if(unit=="Microinch")    return Microinch;
  if(unit=="Mil")          return Mil;
  if(unit=="Yard")         return Yard;
  if(unit=="Angstrom")     return Angstrom;
  if(unit=="Nanometer")    return Nanometer;
  if(unit=="Micron")       return Micron;
  if(unit=="Decimeter")    return Decimeter;
  if(unit=="Decameter")    return Decameter;
  if(unit=="Hectometer")   return Hectometer;
  if(unit=="Gigameter")    return Gigameter;
  if(unit=="Astro")        return Astro;
  if(unit=="Lightyear")    return Lightyear;
  if(unit=="Parsec")       return Parsec;

  if(ok) *ok=false;
  return None;
}



/**
 * Gets a string from a unit enum.
 */
char*
DL_Units::unit2string(Unit unit)
{
	switch(unit) {
    case None:         return "None";
    case Inch:         return "Inch";
    case Foot:         return "Foot";
    case Mile:         return "Mile";
    case Millimeter:   return "Millimeter";
    case Centimeter:   return "Centimeter";
    case Meter:        return "Meter";
    case Kilometer:    return "Kilometer";
    case Microinch:    return "Microinch";
    case Mil:          return "Mil";
    case Yard:         return "Yard";
    case Angstrom:     return "Angstrom";
    case Nanometer:    return "Nanometer";
    case Micron:       return "Micron";
    case Decimeter:    return "Decimeter";
    case Decameter:    return "Decameter";
    case Hectometer:   return "Hectometer";
    case Gigameter:    return "Gigameter";
    case Astro:        return "Astro";
    case Lightyear:    return "Lightyear";
    case Parsec:       return "Parsec";
  }

  return "None";
}



/**
 * Converts a DXF integer () to a Unit enum.
 */
DL_Units::Unit
DL_Units::dxfint2unit(int dxfint)
{
	switch(dxfint) {
		default:
    case  0: return None;
    case  1: return Inch;
    case  2: return Foot;
    case  3: return Mile;
    case  4: return Millimeter;
    case  5: return Centimeter;
    case  6: return Meter;
    case  7: return Kilometer;
    case  8: return Microinch;
    case  9: return Mil;
    case 10: return Yard;
    case 11: return Angstrom;
    case 12: return Nanometer;
    case 13: return Micron;
    case 14: return Decimeter;
    case 15: return Decameter;
    case 16: return Hectometer;
    case 17: return Gigameter;
    case 18: return Astro;
    case 19: return Lightyear;
    case 20: return Parsec;
  }
}


// EOF
