/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#include "dl_vector.h"
#include "dl_math.h"

/**
 * Constructor for a point with default coordinates
 */
DL_Vector::DL_Vector ()
{
	x = 0.0;
	y = 0.0;
	z = 0.0;
}



/**
 * Constructor for a point with given coordinates
 */
DL_Vector::DL_Vector (double vx, double vy, double vz)
{
	x = vx;
	y = vy;
	z = vz;
}



/**
 * Sets a new position for the point.
 */
void 
DL_Vector::set (double vx, double vy, double vz)
{
	x = vx;
	y = vy;
	z = vz;
}



std::ostream& operator << (std::ostream& os, DL_Vector& p)
{
	os << p.x << "/" << p.y << "/" << p.z;
	return os;
}


/** + operator
*/
DL_Vector 
DL_Vector::operator + (const DL_Vector& v)
{
  return DL_Vector(x + v.x, y + v.y, z + v.z);
}


/** - operator
*/
DL_Vector 
DL_Vector::operator - (const DL_Vector& v)
{
  return DL_Vector(x - v.x, y - v.y, z - v.z);
}


/** += operator
 */
void
DL_Vector::operator += (const DL_Vector& v)
{
	x += v.x;
	y += v.y;
	z += v.z;
}


/** -= operator
 */
void
DL_Vector::operator -= (const DL_Vector& v)
{
	x -= v.x;
	y -= v.y;
	z -= v.z;
}


/**
 * *= operator
 */
void 
DL_Vector::operator *= (float s)
{
	x *= s;
	y *= s;
	z *= s;
}


/** Returns a vector with the minimum values from the vectors v1 and v2
*/
DL_Vector 
DL_Vector::minimum (DL_Vector v1, DL_Vector v2)
{
	DL_Vector tmp(min (v1.x, v2.x),
	              min (v1.y, v2.y),
	              min (v1.z, v2.z));
	
	return tmp;
}


/** Returns a vector with the maximum values from the vectors v1 and v2
*/
DL_Vector 
DL_Vector::maximum (DL_Vector v1, DL_Vector v2)
{
	return DL_Vector (max (v1.x, v2.x),
	                  max (v1.y, v2.y),
	                  max (v1.z, v2.z));
}

// EOF
