/*****************************************************************************
**  This is part of the dxflib library
**  Copyright (C) 2000 Andrew Mustun
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#ifndef DL_VECTOR_H
#define DL_VECTOR_H

#include <iostream>

/**
 * Represents a 3d vector (x/y/z)
 *
 * @author Andrew Mustun
 */
class DL_Vector {
	public:
		DL_Vector ();
		DL_Vector (double vx, double vy, double vz=0.0);
		
		void set (double vx, double vy, double vz=0.0);
		
		friend std::ostream& operator << (std::ostream&, DL_Vector& p);
		
		DL_Vector operator + (const DL_Vector& v);
		DL_Vector operator - (const DL_Vector& v);
		
		void operator *= (float s);
		void operator += (const DL_Vector& v);
		void operator -= (const DL_Vector& v);
		
		static DL_Vector minimum (DL_Vector v1, DL_Vector v2);
		static DL_Vector maximum (DL_Vector v1, DL_Vector v2);

	public:
		double x;
		double y;
		double z;
};

#endif

// EOF
